"use strict";

exports.__esModule = true;
exports.useCodeMirror = useCodeMirror;

var _react = require("react");

var _basicSetup = require("@codemirror/basic-setup");

var _state = require("@codemirror/state");

var _commands = require("@codemirror/commands");

var _view = require("@codemirror/view");

function useCodeMirror(props) {
  var value = props.value,
      selection = props.selection,
      onChange = props.onChange,
      _props$extensions = props.extensions,
      extensions = _props$extensions === void 0 ? [] : _props$extensions;

  var _useState = (0, _react.useState)(props.container),
      container = _useState[0],
      setContainer = _useState[1];

  var _useState2 = (0, _react.useState)(),
      view = _useState2[0],
      setView = _useState2[1];

  var _useState3 = (0, _react.useState)(),
      state = _useState3[0],
      setState = _useState3[1];

  (0, _react.useEffect)(function () {
    if (container && !state) {
      var updateListener = _view.EditorView.updateListener.of(function (vu) {
        if (vu.docChanged && typeof onChange === 'function') {
          var doc = vu.state.doc;

          var _value = doc.toString();

          onChange(_value, vu);
        }
      });

      var stateCurrent = _state.EditorState.create({
        doc: value,
        selection: selection,
        extensions: [_basicSetup.basicSetup, _view.keymap.of([_commands.indentWithTab]), updateListener].concat(extensions)
      });

      setState(stateCurrent);

      if (!view) {
        var viewCurrent = new _view.EditorView({
          state: stateCurrent,
          parent: container
        });
        setView(viewCurrent);
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [container, state]);
  (0, _react.useEffect)(function () {
    return function () {
      if (view) {
        view.destroy();
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  (0, _react.useEffect)(function () {
    if (view) {
      var currentValue = view.state.doc.toString();
      view.dispatch({
        changes: {
          from: 0,
          to: currentValue.length,
          insert: value || ''
        }
      });
    }
  }, [value, view]);
  return {
    state: state,
    view: view,
    container: container,
    setContainer: setContainer
  };
}
//# sourceMappingURL=useCodeMirror.js.map