import { useEffect, useState } from 'react';
import { basicSetup } from "@codemirror/basic-setup";
import { EditorState } from "@codemirror/state";
import { indentWithTab } from "@codemirror/commands";
import { EditorView, keymap } from "@codemirror/view";
export function useCodeMirror(props) {
  var value = props.value,
      selection = props.selection,
      onChange = props.onChange,
      _props$extensions = props.extensions,
      extensions = _props$extensions === void 0 ? [] : _props$extensions;

  var _useState = useState(props.container),
      container = _useState[0],
      setContainer = _useState[1];

  var _useState2 = useState(),
      view = _useState2[0],
      setView = _useState2[1];

  var _useState3 = useState(),
      state = _useState3[0],
      setState = _useState3[1];

  useEffect(function () {
    if (container && !state) {
      var updateListener = EditorView.updateListener.of(function (vu) {
        if (vu.docChanged && typeof onChange === 'function') {
          var doc = vu.state.doc;

          var _value = doc.toString();

          onChange(_value, vu);
        }
      });
      var stateCurrent = EditorState.create({
        doc: value,
        selection: selection,
        extensions: [basicSetup, keymap.of([indentWithTab]), updateListener].concat(extensions)
      });
      setState(stateCurrent);

      if (!view) {
        var viewCurrent = new EditorView({
          state: stateCurrent,
          parent: container
        });
        setView(viewCurrent);
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [container, state]);
  useEffect(function () {
    return function () {
      if (view) {
        view.destroy();
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(function () {
    if (view) {
      var currentValue = view.state.doc.toString();
      view.dispatch({
        changes: {
          from: 0,
          to: currentValue.length,
          insert: value || ''
        }
      });
    }
  }, [value, view]);
  return {
    state: state,
    view: view,
    container: container,
    setContainer: setContainer
  };
}
//# sourceMappingURL=useCodeMirror.js.map