import { useEffect, useState } from 'react';
import { basicSetup } from "@codemirror/basic-setup";
import { EditorState } from "@codemirror/state";
import { indentWithTab } from "@codemirror/commands";
import { EditorView, keymap, ViewUpdate } from "@codemirror/view";
import { ReactCodeMirrorProps } from './';

export interface UseCodeMirror extends ReactCodeMirrorProps {
  value?: string;
  container?: HTMLDivElement | null;
}

export function useCodeMirror(props: UseCodeMirror) {
  const { value, selection, onChange, extensions = [] } = props;
  const [container, setContainer] = useState(props.container);
  const [view, setView] = useState<EditorView>();
  const [state, setState] = useState<EditorState>();
  useEffect(() => {
    if (container && !state) {
      const updateListener = EditorView.updateListener.of((vu: ViewUpdate) => {
        if (vu.docChanged && typeof onChange === 'function') {
          const doc = vu.state.doc;
          const value = doc.toString();
          onChange(value, vu);
        }
      });
      const stateCurrent = EditorState.create({
        doc: value,
        selection,
        extensions: [basicSetup, keymap.of([indentWithTab]), updateListener, ...extensions],
      });
      setState(stateCurrent);
      if (!view) {
        const viewCurrent = new EditorView({ state: stateCurrent, parent: container as any });
        setView(viewCurrent);
      }
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [container, state]);

  useEffect(() => {
    return () => {
      if (view) {
        view.destroy();
      }
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  useEffect(() => {
    if (view) {
      const currentValue = view.state.doc.toString();
      view.dispatch({
        changes: { from: 0, to: currentValue.length, insert: value || '' }
      });
    }
  }, [value, view]);

  return { state, view, container, setContainer }
}